@@ -913,10 +913,102 @@ fn background_color_is_rendered() {
         .stdout(file::is_png().with_contents("tests/fixtures/gimp-wilber-ref.png"));
 }
 
+#[test]
+fn background_color_rgb() {
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg("--background-color=rgb(0, 255, 0)")
+        .assert()
+        .success()
+        .stdout(file::is_png().with_contents("tests/fixtures/lime-ref.png"));
+}
+
+#[test]
+fn background_color_rgba() {
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg("--background-color=rgba(0, 255, 0, 0.5)")
+        .assert()
+        .success()
+        .stdout(file::is_png().with_contents("tests/fixtures/lime-transparent-ref.png"));
+}
+
+#[test]
+fn background_color_hsl() {
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg("--background-color=hsl(120, 100%, 50%)")
+        .assert()
+        .success()
+        .stdout(file::is_png().with_contents("tests/fixtures/lime-ref.png"));
+}
+
+#[test]
+fn background_color_hsla() {
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg("--background-color=hsla(120, 100%, 50%, 0.5)")
+        .assert()
+        .success()
+        .stdout(file::is_png().with_contents("tests/fixtures/lime-transparent-ref.png"));
+}
+
+#[test]
+fn background_color_hwb() {
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg("--background-color=hwb(120 0% 0%)")
+        .assert()
+        .success()
+        .stdout(file::is_png().with_contents("tests/fixtures/lime-ref.png"));
+}
+
+#[test]
+fn background_color_hwba() {
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg("--background-color=hwb(120 0% 0% / 0.5)")
+        .assert()
+        .success()
+        .stdout(file::is_png().with_contents("tests/fixtures/lime-transparent-ref.png"));
+}
+
+fn test_unsupported_background_color(color: &str) {
+    let color_arg = format!("--background-color={color}");
+    RsvgConvert::new_with_input("tests/fixtures/empty-10x10.svg")
+        .arg("--width=10")
+        .arg("--height=10")
+        .arg(&color_arg)
+        .assert()
+        .failure()
+        .stderr(contains("Invalid value").and(contains("unsupported color syntax")));
+}
+
+#[test]
+fn unsupported_background_color() {
+    let colors = [
+        "lab(62.2345% -34.9638 47.7721)",
+        "lch(62.2345% 59.2 126.2)",
+        "oklab(66.016% -0.1084 0.1114)",
+        "oklch(0.66016 0.15546 134.231)",
+        "color(display-p3 -0.6112 1.0079 -0.2192)",
+    ];
+
+    for c in &colors {
+        test_unsupported_background_color(c);
+    }
+}
+
 #[test]
 fn stylesheet_option() {
     RsvgConvert::new_with_input("tests/fixtures/dpi.svg")
-        .arg("--stylesheet=tests/fixtures/empty.svg")
+        .arg("--stylesheet=tests/fixtures/empty.css")
         .assert()
         .success();
 }
@@ -925,7 +1017,7 @@ fn stylesheet_option() {
 fn stylesheet_short_option() {
     RsvgConvert::new_with_input("tests/fixtures/dpi.svg")
         .arg("-s")
-        .arg("tests/fixtures/empty.svg")
+        .arg("tests/fixtures/empty.css")
         .assert()
         .success();
 }
